==> haskell-xcb-types-0.10.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcb-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xcb-types
version:              0.10.0
visibility:           public
id:                   xcb-types-0.10.0-ImhL6PPHKpD7aCjWcgMx5L
key:                  xcb-types-0.10.0-ImhL6PPHKpD7aCjWcgMx5L
license:              BSD-3-Clause
maintainer:           Antoine Latter <aslatter@gmail.com>
author:               Antoine Latter
homepage:             http://community.haskell.org/~aslatter/code/xcb-types
synopsis:             Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.

    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.

    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.

    This package parses these XML files into Haskell data structures.

    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.

    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.13.

category:             Data
abi:                  9ff44fb7f4803341f4d2eb72b0130f3a
exposed:              True
exposed-modules:
    Data.XCB Data.XCB.FromXML Data.XCB.Pretty Data.XCB.Types

hidden-modules:       Data.XCB.Utils
import-dirs:          /usr/lib/ghc-8.8.1/site-local/xcb-types-0.10.0
library-dirs:         /usr/lib/ghc-8.8.1/site-local/xcb-types-0.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/xcb-types-0.10.0
hs-libraries:         HSxcb-types-0.10.0-ImhL6PPHKpD7aCjWcgMx5L
depends:
    base-4.13.0.0 containers-0.6.2.1 mtl-2.2.2 pretty-1.1.3.6
    xml-1.3.14-A6bMPsWCgyp2aJRE11Eckt

haddock-interfaces:   /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html:         /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcb-types-0.10.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcb-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xcb-types
version:              0.10.0
visibility:           public
id:                   xcb-types-0.10.0-6x8WFAS8AFjIBAHwDXO2JQ
key:                  xcb-types-0.10.0-6x8WFAS8AFjIBAHwDXO2JQ
license:              BSD-3-Clause
maintainer:           Antoine Latter <aslatter@gmail.com>
author:               Antoine Latter
homepage:             http://community.haskell.org/~aslatter/code/xcb-types
synopsis:             Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.

    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.

    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.

    This package parses these XML files into Haskell data structures.

    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.

    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.13.

category:             Data
abi:                  9c5e95fb520b55bf35ab6e7d2f818f3b
exposed:              True
exposed-modules:
    Data.XCB Data.XCB.FromXML Data.XCB.Pretty Data.XCB.Types

hidden-modules:       Data.XCB.Utils
import-dirs:          /usr/lib/ghc-8.8.3/site-local/xcb-types-0.10.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/xcb-types-0.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/xcb-types-0.10.0
hs-libraries:         HSxcb-types-0.10.0-6x8WFAS8AFjIBAHwDXO2JQ
depends:
    base-4.13.0.0 containers-0.6.2.1 mtl-2.2.2 pretty-1.1.3.6
    xml-1.3.14-IT4S7IkihY28IGBFVjHe4u

haddock-interfaces:   /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html:         /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
